==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fen__5fUS__5fPOSIX.h <==
// public class gnu.java.locale.LocaleInformation_en_US_POSIX

// class file dependencies
// @dep_class b315896519014100 gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX_H_
#define _JC_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods	gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs {
    _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs	gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs	gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object {
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fen__5fUS__5fPOSIX.h <==
// public class gnu.java.locale.LocaleInformation_en_US_POSIX

// class file dependencies
// @dep_class b315896519014100 gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX_H_
#define _JC_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$fields_struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vmethods	gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs {
    _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_refs	gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$sub_nonrefs	gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$object {
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$vtype _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fen__5fUS__5fPOSIX_H_ */
